Package com.google.debugging.sourcemap
Class SourceMapConsumerFactory
java.lang.Object
com.google.debugging.sourcemap.SourceMapConsumerFactory
Detect and parse the provided source map.
-
Method Summary
Modifier and TypeMethodDescriptionstatic SourceMappingstatic SourceMappingparse(String contents, @Nullable SourceMapSupplier supplier) static SourceMapConsumerV3Using the fast parser to parse the source map.
-
Method Details
-
parse
- Parameters:
contents- The string representing the source map file contents.- Returns:
- The parsed source map.
- Throws:
SourceMapParseException
-
parse
public static SourceMapping parse(String contents, @Nullable SourceMapSupplier supplier) throws SourceMapParseException - Parameters:
contents- The string representing the source map file contents.supplier- A supplier for any referenced maps.- Returns:
- The parsed source map.
- Throws:
SourceMapParseException
-
parseFast
Using the fast parser to parse the source map. This only supports version 3 source maps.- Parameters:
contents- The string representing the source map file contents.- Returns:
- The parsed source map.
- Throws:
SourceMapParseException
-