Record Class SourceMapSection

java.lang.Object
java.lang.Record
com.google.debugging.sourcemap.SourceMapSection

public record SourceMapSection(SourceMapSection.SectionType type, String value, int line, int column) extends Record
A class representing a partial source map.
  • Constructor Details

    • SourceMapSection

      public SourceMapSection(SourceMapSection.SectionType type, String value, int line, int column)
      Creates an instance of a SourceMapSection record class.
      Parameters:
      type - the value for the type record component
      value - the value for the value record component
      line - the value for the line record component
      column - the value for the column record component
  • Method Details

    • forMap

      public static SourceMapSection forMap(String value, int line, int column)
    • forURL

      public static SourceMapSection forURL(String value, int line, int column)
    • getSectionType

      public SourceMapSection.SectionType getSectionType()
    • getSectionValue

      public String getSectionValue()
      Returns the value that represents the map for this section. This is either a URL for a valid source map file that represents a section of a generate source file such as when multiple files are concatenated together, or a string representing a JSON object that is a source map.
    • getLine

      public int getLine()
      Returns the starting line for this section
    • getColumn

      public int getColumn()
      Returns the starting column for this section
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared with Objects::equals(Object,Object); primitive components are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • type

      Returns the value of the type record component.
      Returns:
      the value of the type record component
    • value

      public String value()
      Returns the value of the value record component.
      Returns:
      the value of the value record component
    • line

      public int line()
      Returns the value of the line record component.
      Returns:
      the value of the line record component
    • column

      public int column()
      Returns the value of the column record component.
      Returns:
      the value of the column record component