Enum Class CompilerOptions.ExperimentalForceTranspile

java.lang.Object
java.lang.Enum<CompilerOptions.ExperimentalForceTranspile>
com.google.javascript.jscomp.CompilerOptions.ExperimentalForceTranspile
All Implemented Interfaces:
Serializable, Comparable<CompilerOptions.ExperimentalForceTranspile>, Constable
Enclosing class:
CompilerOptions

@Deprecated public static enum CompilerOptions.ExperimentalForceTranspile extends Enum<CompilerOptions.ExperimentalForceTranspile>
Deprecated.
Options to force transpile specific features for performance experiments.
  • Enum Constant Details

    • ALL_EXCEPT_ASYNC_AWAIT

      @Deprecated public static final CompilerOptions.ExperimentalForceTranspile ALL_EXCEPT_ASYNC_AWAIT
      Deprecated.
      Use setLanguageOut(LanguageMode.ECMASCRIPT5), or setLangaugeOut(LanguageMode.ECMASCRIPT_2017) instead.
      Transpile all features down to ES5 except ASYNC AWAIT
  • Method Details

    • values

      Deprecated.
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static CompilerOptions.ExperimentalForceTranspile valueOf(String name)
      Deprecated.
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null