Package com.google.javascript.jscomp
Class IdMappingUtil
java.lang.Object
com.google.javascript.jscomp.IdMappingUtil
A utility class for generating and parsing id mappings held by
ReplaceIdGenerators.-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classA stateful pull parser for reading id mapping sections and entries line by line. -
Method Summary
Modifier and TypeMethodDescriptionparseSectionAsStream(InputStream stream, String sectionFilter) parseSerializedIdMappings(String idMappings)
-
Method Details
-
parseSectionAsStream
public static com.google.common.collect.ImmutableMap<String,String> parseSectionAsStream(InputStream stream, String sectionFilter) throws IOException - Throws:
IOException
-
parseSerializedIdMappings
public static Map<String,com.google.common.collect.BiMap<String, parseSerializedIdMappingsString>> (BufferedReader br) throws IOException - Throws:
IOException
-
parseSerializedIdMappings
-