Record Class JSChunkGraph.DependencyManagementResult

java.lang.Object
java.lang.Record
com.google.javascript.jscomp.JSChunkGraph.DependencyManagementResult
Enclosing class:
JSChunkGraph

public static record JSChunkGraph.DependencyManagementResult(com.google.common.collect.ImmutableList<CompilerInput> orderedInputs, SortedDependencies<CompilerInput> sorter, com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs) extends Record
  • Constructor Details

    • DependencyManagementResult

      public DependencyManagementResult(com.google.common.collect.ImmutableList<CompilerInput> orderedInputs, SortedDependencies<CompilerInput> sorter, com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs)
      Creates an instance of a DependencyManagementResult record class.
      Parameters:
      orderedInputs - the value for the orderedInputs record component
      sorter - the value for the sorter record component
      entryPointInputs - the value for the entryPointInputs record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • orderedInputs

      public com.google.common.collect.ImmutableList<CompilerInput> orderedInputs()
      Returns the value of the orderedInputs record component.
      Returns:
      the value of the orderedInputs record component
    • sorter

      Returns the value of the sorter record component.
      Returns:
      the value of the sorter record component
    • entryPointInputs

      public com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs()
      Returns the value of the entryPointInputs record component.
      Returns:
      the value of the entryPointInputs record component