Class ReportUntranspilableFeatures

java.lang.Object
com.google.javascript.jscomp.ReportUntranspilableFeatures

public final class ReportUntranspilableFeatures extends Object
Looks for presence of features that are not supported for transpilation (mostly new RegExp features and bigint literal).

Reports errors for any features are present in the root and not present in the targeted output language.

Note: the errors reported by this pass are suppressible. In most cases the right thing to do if suppressing them is instead to bump the output language level; for example, someone who only needs to support ES2020 but is setting --language_out=ECMASCRIPT_2015 will see errors on ES2018 regex literal syntax. The best solution is to set --language_out=ECMASCRIPT_2020. A second solution, which we support but do not recommend, is to suppress these errors invalid input: '&' let the compiler silently output untranspiled ES2018 regex literals.

  • Field Details

    • UNTRANSPILABLE_FEATURE_PRESENT

      public static final DiagnosticType UNTRANSPILABLE_FEATURE_PRESENT
    • UNSUPPORTED_FEATURE_PRESENT

      public static final DiagnosticType UNSUPPORTED_FEATURE_PRESENT