Class VerifyingErrorManager

java.lang.Object
com.google.javascript.jscomp.ThreadSafeDelegatingErrorManager
com.google.javascript.jscomp.VerifyingErrorManager
All Implemented Interfaces:
ErrorHandler, ErrorManager

public final class VerifyingErrorManager extends ThreadSafeDelegatingErrorManager
An ErrorManager that verifies expected diagnostics and reports missing or unexpected ones.

It wraps a delegate ErrorManager. Expected diagnostics (passed as regexes) are swallowed if matched. Unexpected diagnostics are passed to the delegate. At the end of compilation (when generateReport is called), any unmatched expectations are reported as errors to the delegate.