Uses of Interface
com.google.javascript.jscomp.ErrorManager
Packages that use ErrorManager
Package
Description
-
Uses of ErrorManager in com.google.javascript.jscomp
Classes in com.google.javascript.jscomp that implement ErrorManagerModifier and TypeClassDescriptionclassDeprecated.final classAn ErrorManager that silently swallows all messages.final classAn error manager that logs errors and warnings using a logger in addition to collecting them in memory.classDeprecated., Please use the {#SortingErrorManger} with a {#PrintStreamErrorReportGenerator} instead.classA customizable error manager that sorts all errors and warnings reported to it, and has customizable output through theSortingErrorManager.ErrorReportGeneratorinterface.classA simple delegatingErrorManagerthat provides a thread-safe wrapper for the one being delegated.final classAn ErrorManager that verifies expected diagnostics and reports missing or unexpected ones.Methods in com.google.javascript.jscomp that return ErrorManagerModifier and TypeMethodDescriptionabstract ErrorManagerAbstractCompiler.getErrorManager()Gets the error manager.Compiler.getErrorManager()Methods in com.google.javascript.jscomp with parameters of type ErrorManagerModifier and TypeMethodDescription@Nullable SourceMapConsumerV3SourceMapInput.getSourceMap(ErrorManager errorManager) Gets the source map, reading from disk and parsing if necessary.voidCompiler.setErrorManager(ErrorManager errorManager) Sets the error manager.Constructors in com.google.javascript.jscomp with parameters of type ErrorManagerModifierConstructorDescriptionCompiler(ErrorManager errorManager) Creates a Compiler that uses a custom error manager.ThreadSafeDelegatingErrorManager(ErrorManager delegated) VerifyingErrorManager(ErrorManager delegate, List<String> expectedDiagnostics) -
Uses of ErrorManager in com.google.javascript.jscomp.ant
Classes in com.google.javascript.jscomp.ant that implement ErrorManagerModifier and TypeClassDescriptionfinal classAn error manager that pipes warnings and errors properly into the Ant task infrastructure. -
Uses of ErrorManager in com.google.javascript.jscomp.deps
Constructors in com.google.javascript.jscomp.deps with parameters of type ErrorManagerModifierConstructorDescriptionDepsFileRegexParser(com.google.common.base.Function<String, String> pathTranslator, ErrorManager errorManager) DepsFileRegexParser(ErrorManager errorManager) ConstructorDepsGenerator(Collection<SourceFile> deps, Collection<SourceFile> srcs, DepsGenerator.InclusionStrategy mergeStrategy, String closurePathAbs, ErrorManager errorManager, ModuleLoader loader) Creates a new DepsGenerator.JsFileLineParser(ErrorManager errorManager) Constructor.JsFileRegexParser(ErrorManager errorManager) Constructor -
Uses of ErrorManager in com.google.javascript.refactoring
Classes in com.google.javascript.refactoring that implement ErrorManagerModifier and TypeClassDescriptionclassAn error manager that finds a SuggestedFix for all errors if possible.