Enum Class JSDocInfo.PerFileClosureUnawareMode

java.lang.Object
java.lang.Enum<JSDocInfo.PerFileClosureUnawareMode>
com.google.javascript.rhino.JSDocInfo.PerFileClosureUnawareMode
All Implemented Interfaces:
Serializable, Comparable<JSDocInfo.PerFileClosureUnawareMode>, Constable
Enclosing class:
JSDocInfo

public static enum JSDocInfo.PerFileClosureUnawareMode extends Enum<JSDocInfo.PerFileClosureUnawareMode>
Configures whether any @closureUnaware blocks in a file will go through any compiler optimization passes or transpilation.

SIMPLE: the file goes through a predefined set of safe optimizations invalid input: '&' transpilation

WHITESPACE: the file goes through no optimizations or transpilation, although code printing does strip unnecessary whitespace and comments.

UNSPECIFIED: indicates the annotation was just `@closureUnaware` with no mode specified. Currently this is equivalent to SIMPLE.