Enum Class Node.RecursionMode

java.lang.Object
java.lang.Enum<Node.RecursionMode>
com.google.javascript.rhino.Node.RecursionMode
All Implemented Interfaces:
Serializable, Comparable<Node.RecursionMode>, Constable
Enclosing class:
Node

public static enum Node.RecursionMode extends Enum<Node.RecursionMode>
  • Enum Constant Details

    • SHALLOW

      public static final Node.RecursionMode SHALLOW
      Do not compare children or shadow AST.
    • DEEP_NO_SHADOW

      public static final Node.RecursionMode DEEP_NO_SHADOW
      Recursively compare children but not shadow AST.
    • DEEP

      public static final Node.RecursionMode DEEP
      Recursively compare children and shadow AST.
  • Method Details

    • values

      public static Node.RecursionMode[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Node.RecursionMode valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • recurseShadowAst

      public boolean recurseShadowAst()
    • recurseChildren

      public boolean recurseChildren()