Uses of Enum Class
com.google.javascript.rhino.JSDocInfo.PerFileClosureUnawareMode
Packages that use JSDocInfo.PerFileClosureUnawareMode
-
Uses of JSDocInfo.PerFileClosureUnawareMode in com.google.javascript.rhino
Methods in com.google.javascript.rhino that return JSDocInfo.PerFileClosureUnawareModeModifier and TypeMethodDescription@Nullable JSDocInfo.PerFileClosureUnawareModeJSDocInfo.getPerFileClosureUnawareMode()Returns the value of the@perFileClosureUnawareModeannotation, or null if not present.Returns the enum constant of this class with the specified name.static JSDocInfo.PerFileClosureUnawareMode[]JSDocInfo.PerFileClosureUnawareMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in com.google.javascript.rhino with parameters of type JSDocInfo.PerFileClosureUnawareModeModifier and TypeMethodDescriptionbooleanJSDocInfo.Builder.recordClosureUnawareCode(JSDocInfo.PerFileClosureUnawareMode mode) Records that this JSDoc was annotated with the@closureUnawareannotation.