Uses of Enum Class
com.google.javascript.rhino.Node.RecursionMode
Packages that use Node.RecursionMode
-
Uses of Node.RecursionMode in com.google.javascript.rhino
Methods in com.google.javascript.rhino that return Node.RecursionModeModifier and TypeMethodDescriptionstatic Node.RecursionModeReturns the enum constant of this class with the specified name.static Node.RecursionMode[]Node.RecursionMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in com.google.javascript.rhino with parameters of type Node.RecursionModeModifier and TypeMethodDescriptionbooleanNode.isEquivalentTo(Node node, Node.RecursionMode recursion, Node.TypeComparison typeConfig, Node.JsDocComparison jsDocConfig, Node.SideEffectComparison sideEffectConfig) Returns whether this node is equivalent semantically to the provided node.