Deprecated API
Contents
-
Deprecated ClassesClassDescription, Please use the {#SortingErrorManger} with a {#PrintStreamErrorReportGenerator} instead.
-
Deprecated Enum Classes
-
Deprecated Fields
-
Deprecated MethodsMethodDescriptionsince this has a default value and is never checked, you can safely remove any overrides of this method from your coding conventions.StripCode is deprecated. Code should be designed to be removed by other means.See go/binary-level-conformance-deprecated.See go/binary-level-conformance-deprecated.This is a no-op.StripCode is deprecated. Code should be designed to be removed by other means.StripCode is deprecated. Code should be designed to be removed by other means.StripCode is deprecated. Code should be designed to be removed by other means.use getPropertyCollapseLevelcom.google.javascript.jscomp.DependencyOptions.pruneLegacyForEntryPoints
(Iterable<ModuleIdentifier>) PreferDependencyOptions.pruneForEntryPoints(Iterable)with a complete list of entry points.because we want to control the input node tokens accepted by this function. UsegetBestJSDocInfoNodeStrictinstead.Please useFeatureSet.version()instead.replace uses of this method with a more precise definition of a pass configuration.Do not add new uses to the method. This method exists only for migration purposes. Removing passes piecemeal is very fragile.alias ofSourceFile.getName(). Use that insteadThis method is quite heuristic, looking for @type annotations that start with "function". Other methods like containsDeclaration() and containsTypeDefinition are generally preferred.PreferJSType.isSubtype(JSType)instead."original name" is poorly defined."original name" is poorly defined. See #getOriginalName
-
Deprecated ConstructorsConstructorDescriptionthe inputId is read from the SourceFile. Use CompilerInput(file, isExtern)the inputId is read from the SourceFile. Use CompilerInput(file, isExtern)
-
Deprecated Enum ConstantsEnum ConstantDescriptioncom.google.javascript.jscomp.CompilerOptions.ExperimentalForceTranspile.PERFORMANT_WITH_ASYNC_STACKSUse setLanguageOut(LanguageMode.ECMASCRIPT5), or setLangaugeOut(LanguageMode.ECMASCRIPT_2017) instead.