Package com.google.debugging.sourcemap
Record Class SourceMapSection
java.lang.Object
java.lang.Record
com.google.debugging.sourcemap.SourceMapSection
public record SourceMapSection(SourceMapSection.SectionType type, String value, int line, int column)
extends Record
A class representing a partial source map.
-
Nested Class Summary
Nested Classes -
Constructor Summary
ConstructorsConstructorDescriptionSourceMapSection(SourceMapSection.SectionType type, String value, int line, int column) Creates an instance of aSourceMapSectionrecord class. -
Method Summary
Modifier and TypeMethodDescriptionintcolumn()Returns the value of thecolumnrecord component.final booleanIndicates whether some other object is "equal to" this one.static SourceMapSectionstatic SourceMapSectionintReturns the starting column for this sectionintgetLine()Returns the starting line for this sectionReturns the value that represents the map for this section.final inthashCode()Returns a hash code value for this object.intline()Returns the value of thelinerecord component.final StringtoString()Returns a string representation of this record class.type()Returns the value of thetyperecord component.value()Returns the value of thevaluerecord component.
-
Constructor Details
-
SourceMapSection
Creates an instance of aSourceMapSectionrecord class.- Parameters:
type- the value for thetyperecord componentvalue- the value for thevaluerecord componentline- the value for thelinerecord componentcolumn- the value for thecolumnrecord component
-
-
Method Details
-
forMap
-
forURL
-
getSectionType
-
getSectionValue
Returns the value that represents the map for this section. This is either a URL for a valid source map file that represents a section of a generate source file such as when multiple files are concatenated together, or a string representing a JSON object that is a source map. -
getLine
public int getLine()Returns the starting line for this section -
getColumn
public int getColumn()Returns the starting column for this section -
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
type
Returns the value of thetyperecord component.- Returns:
- the value of the
typerecord component
-
value
Returns the value of thevaluerecord component.- Returns:
- the value of the
valuerecord component
-
line
public int line()Returns the value of thelinerecord component.- Returns:
- the value of the
linerecord component
-
column
public int column()Returns the value of thecolumnrecord component.- Returns:
- the value of the
columnrecord component
-