Package com.google.javascript.jscomp
Enum Class CompilerOptions.ExperimentalForceTranspile
java.lang.Object
java.lang.Enum<CompilerOptions.ExperimentalForceTranspile>
com.google.javascript.jscomp.CompilerOptions.ExperimentalForceTranspile
- All Implemented Interfaces:
Serializable,Comparable<CompilerOptions.ExperimentalForceTranspile>,Constable
- Enclosing class:
CompilerOptions
@Deprecated
public static enum CompilerOptions.ExperimentalForceTranspile
extends Enum<CompilerOptions.ExperimentalForceTranspile>
Deprecated.
Options to force transpile specific features for performance experiments.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionDeprecated.Use setLanguageOut(LanguageMode.ECMASCRIPT5), or setLangaugeOut(LanguageMode.ECMASCRIPT_2017) instead. -
Method Summary
Modifier and TypeMethodDescriptionDeprecated.Returns the enum constant of this class with the specified name.values()Deprecated.Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
PERFORMANT_WITH_ASYNC_STACKS
@Deprecated public static final CompilerOptions.ExperimentalForceTranspile PERFORMANT_WITH_ASYNC_STACKSDeprecated.Use setLanguageOut(LanguageMode.ECMASCRIPT5), or setLangaugeOut(LanguageMode.ECMASCRIPT_2017) instead.Transpile performance sensitive features away, preserving ASYNC/AWAIT for debuggability
-
-
Method Details
-
values
Deprecated.Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Deprecated.Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-