Package com.google.javascript.jscomp
Record Class JSChunkGraph.DependencyManagementResult
java.lang.Object
java.lang.Record
com.google.javascript.jscomp.JSChunkGraph.DependencyManagementResult
- Enclosing class:
JSChunkGraph
public static record JSChunkGraph.DependencyManagementResult(com.google.common.collect.ImmutableList<CompilerInput> orderedInputs, SortedDependencies<CompilerInput> sorter, com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs)
extends Record
-
Constructor Summary
ConstructorsConstructorDescriptionDependencyManagementResult(com.google.common.collect.ImmutableList<CompilerInput> orderedInputs, SortedDependencies<CompilerInput> sorter, com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs) Creates an instance of aDependencyManagementResultrecord class. -
Method Summary
Modifier and TypeMethodDescriptioncom.google.common.collect.ImmutableSet<CompilerInput> Returns the value of theentryPointInputsrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.com.google.common.collect.ImmutableList<CompilerInput> Returns the value of theorderedInputsrecord component.sorter()Returns the value of thesorterrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
DependencyManagementResult
public DependencyManagementResult(com.google.common.collect.ImmutableList<CompilerInput> orderedInputs, SortedDependencies<CompilerInput> sorter, com.google.common.collect.ImmutableSet<CompilerInput> entryPointInputs) Creates an instance of aDependencyManagementResultrecord class.- Parameters:
orderedInputs- the value for theorderedInputsrecord componentsorter- the value for thesorterrecord componententryPointInputs- the value for theentryPointInputsrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
orderedInputs
Returns the value of theorderedInputsrecord component.- Returns:
- the value of the
orderedInputsrecord component
-
sorter
Returns the value of thesorterrecord component.- Returns:
- the value of the
sorterrecord component
-
entryPointInputs
Returns the value of theentryPointInputsrecord component.- Returns:
- the value of the
entryPointInputsrecord component
-