Package com.google.javascript.rhino
Enum Class JSDocInfo.PerFileClosureUnawareMode
java.lang.Object
java.lang.Enum<JSDocInfo.PerFileClosureUnawareMode>
com.google.javascript.rhino.JSDocInfo.PerFileClosureUnawareMode
- All Implemented Interfaces:
Serializable,Comparable<JSDocInfo.PerFileClosureUnawareMode>,Constable
- Enclosing class:
JSDocInfo
public static enum JSDocInfo.PerFileClosureUnawareMode
extends Enum<JSDocInfo.PerFileClosureUnawareMode>
Configures whether any @closureUnaware blocks in a file will go through any compiler
optimization passes or transpilation.
SIMPLE: the file goes through a predefined set of safe optimizations invalid input: '&' transpilation
WHITESPACE: the file goes through no optimizations or transpilation, although code printing does strip unnecessary whitespace and comments.
UNSPECIFIED: indicates the annotation was just `@closureUnaware` with no mode specified. Currently this is equivalent to SIMPLE.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static JSDocInfo.PerFileClosureUnawareMode[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
UNSPECIFIED
-
SIMPLE
-
WHITESPACE
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-