Package com.google.javascript.rhino
Enum Class Node.RecursionMode
- All Implemented Interfaces:
Serializable,Comparable<Node.RecursionMode>,Constable
- Enclosing class:
Node
Recursion mode for
Node.isEquivalentTo(com.google.javascript.rhino.Node).-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionRecursively compare children and shadow AST.Recursively compare children but not shadow AST.Do not compare children or shadow AST. -
Method Summary
Modifier and TypeMethodDescriptionbooleanbooleanstatic Node.RecursionModeReturns the enum constant of this class with the specified name.static Node.RecursionMode[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
SHALLOW
Do not compare children or shadow AST. -
DEEP_NO_SHADOW
Recursively compare children but not shadow AST. -
DEEP
Recursively compare children and shadow AST.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
recurseShadowAst
public boolean recurseShadowAst() -
recurseChildren
public boolean recurseChildren()
-