JavaScript is disabled on your browser.
Contents
Deprecated Classes
, Please use the {#SortingErrorManger} with a {#PrintStreamErrorReportGenerator}
instead.
Deprecated Methods
since this has a default value and is never checked, you can safely remove any
overrides of this method from your coding conventions.
StripCode is deprecated. Code should be designed to be removed by other means.
See go/binary-level-conformance-deprecated.
See go/binary-level-conformance-deprecated.
StripCode is deprecated. Code should be designed to be removed by other means.
StripCode is deprecated. Code should be designed to be removed by other means.
StripCode is deprecated. Code should be designed to be removed by other means.
use getPropertyCollapseLevel
because we want to control the input node tokens accepted by this function. Use
getBestJSDocInfoNodeStrict instead.
replace uses of this method with a more precise definition of a pass configuration.
Do not add new uses to the method. This method exists only for migration purposes.
Removing passes piecemeal is very fragile.
This method is quite heuristic, looking for @type annotations that start with
"function". Other methods like containsDeclaration() and containsTypeDefinition are
generally preferred.
"original name" is poorly defined.
"original name" is poorly defined. See #getOriginalName
Deprecated Constructors
the inputId is read from the SourceFile. Use CompilerInput(file, isExtern)
the inputId is read from the SourceFile. Use CompilerInput(file, isExtern)
Deprecated Enum Constants
Use setLanguageOut(LanguageMode.ECMASCRIPT5), or
setLangaugeOut(LanguageMode.ECMASCRIPT_2017) instead.